@@ -30,15 +30,21 @@ import os
 
 hubzeroConfFileLocation = "/etc/hubzero.conf"
 
-def getHubzeroConfigOption(headerName, optionName):
+def getHubzeroConfigOption(headerName, optionName, default = None):
 
 	if not os.path.exists(hubzeroConfFileLocation):
 		raise Exception("Cannot find hubzeroConfFileLocation:" + hubzeroConfFileLocation)
 
 	config = ConfigParser.ConfigParser()
+
 	config.readfp(open(hubzeroConfFileLocation))
 
-	return config.get(headerName, optionName)
+        try:
+		value = config.get(headerName, optionName)
+	except ConfigParser.NoOptionError:
+		value = default
+
+	return value
 	
 
 def getHubDefaultSite():
